pub struct NodeDebugLayout {
pub labels: HashMap<Uuid, String>,
}Expand description
For internal use, this struct represents the debug layout of a node. It is used to store the labels of the primitives in the node.
Fields
labels: HashMap<Uuid, String>Auto Trait Implementations
impl Freeze for NodeDebugLayout
impl RefUnwindSafe for NodeDebugLayout
impl Send for NodeDebugLayout
impl Sync for NodeDebugLayout
impl Unpin for NodeDebugLayout
impl UnsafeUnpin for NodeDebugLayout
impl UnwindSafe for NodeDebugLayout